@@ -4,7 +4,7 @@ from aiohttp_rest_api.loader import (
     load_and_connect_all_endpoints_from_folder,
     get_openapi_documentation,
 )
-from aiohttp_rest_api.openapi import setup_redoc
+from aiohttp_rest_api.redoc import setup_redoc
 
 import logging
 
